ApiKey class

ApiKey model class

Constructors

ApiKey({required String key, required DateTime createdAt, DateTime? expiresAt})
API Key requires a key, creation date and expiration date

Properties

createdAt → DateTime
API Key creation date
final
expiresAt → DateTime?
API Key expiration date
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
API Key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited