CustomTemplateEngine class abstract

a Custom Template Engine

Implementers

Constructors

CustomTemplateEngine()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contentType() → ContentType
Returns a ContentType containing the template content type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(String template, Map<String, dynamic> context) → String
Returns a String containing the rendered template
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited