SSLOptions class

SSL Options keyFile - path to the key file certificate - path to the certificate

Constructors

SSLOptions({required String keyFile, required String certificate})
Constructor

Properties

certificate → String
Path to the certificate
final
hashCode → int
The hash code for this object.
no setterinherited
keyFile → String
Path to the key file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited